==> ejc-production-api-3.0.0-20220815.140905-248-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/21
 * @description:
 */
public class ProductionTaskVO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date taskTime; // 生产任务单日期
    private String customerName; // 客户名称
    private String worksiteName; // 工地名称
    private String productName; // 产品名称
    private BigDecimal quantity; // 数量
    private String weighNumber; // 过磅数
    private String notWeighNumber; // 未过磅数量
    private String unitName; // 机组名称
    private BigDecimal addedCount; // 追加后数量


    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public String getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(String weighNumber) {
        this.weighNumber = weighNumber;
    }

    public String getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(String notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public BigDecimal getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(BigDecimal addedCount) {
        this.addedCount = addedCount;
    }
}

==> ejc-production-api-3.0.0-20220930.030749-285-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/21
 * @description:
 */
public class ProductionTaskVO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date taskTime; // 生产任务单日期
    private String customerName; // 客户名称
    private String worksiteName; // 工地名称
    private String productName; // 产品名称
    private BigDecimal quantity; // 数量
    private String weighNumber; // 过磅数
    private String notWeighNumber; // 未过磅数量
    private String unitName; // 机组名称
    private BigDecimal addedCount; // 追加后数量
    private int carCount; // 派车数量

    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public String getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(String weighNumber) {
        this.weighNumber = weighNumber;
    }

    public String getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(String notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public BigDecimal getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(BigDecimal addedCount) {
        this.addedCount = addedCount;
    }

    public int getCarCount() {
        return carCount;
    }

    public void setCarCount(int carCount) {
        this.carCount = carCount;
    }
}
